@@ -64,7 +64,6 @@ __global__
|
||||
void Kernel(typename Operator::Params params) {
|
||||
// Dynamic shared memory base pointer
|
||||
extern __shared__ int SharedStorageBase[];
|
||||
|
||||
// Declare pointer to dynamic shared memory.
|
||||
typename Operator::SharedStorage *shared_storage =
|
||||
reinterpret_cast<typename Operator::SharedStorage *>(SharedStorageBase);
|
||||
@@ -81,13 +80,11 @@ __global__
|
||||
void Kernel2(typename Operator::Params params) {
|
||||
// Dynamic shared memory base pointer
|
||||
extern __shared__ int SharedStorageBase[];
|
||||
|
||||
// Declare pointer to dynamic shared memory.
|
||||
typename Operator::SharedStorage *shared_storage =
|
||||
reinterpret_cast<typename Operator::SharedStorage *>(SharedStorageBase);
|
||||
|
||||
Operator::invoke(params, *shared_storage);
|
||||
|
||||
}
|
||||
|
||||
|
||||
@@ -108,7 +105,6 @@ void device_kernel(CUTLASS_GRID_CONSTANT typename Operator::Params const params)
|
||||
{
|
||||
// Dynamic shared memory base pointer
|
||||
extern __shared__ char smem[];
|
||||
|
||||
Operator op;
|
||||
op(params, smem);
|
||||
}
|
||||
|
||||
Reference in New Issue
Block a user